==> accounts_management-0.1.6.gem: app/controllers/accounts_management/documents/orders_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::OrdersController < AccountsManagementController
    # GET /documents/orders
    # GET /documents/orders.json
    def index
      @documents_orders = Documents::Order.all
  
      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @documents_orders }
      end
    end
  
    # GET /documents/orders/1
    # GET /documents/orders/1.json
    def show
      @documents_order = Documents::Order.find(params[:id])
  
      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @documents_order }
      end
    end
  
    # GET /documents/orders/new
    # GET /documents/orders/new.json
    def new
      @documents_order = Documents::Order.new
  
      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @documents_order }
      end
    end
  
    # GET /documents/orders/1/edit
    def edit
      @documents_order = Documents::Order.find(params[:id])
    end
  
    # POST /documents/orders
    # POST /documents/orders.json
    def create
      @documents_order = Documents::Order.new(params[:documents_order])
  
      respond_to do |format|
        if @documents_order.save
          format.html { redirect_to @documents_order, :notice => 'Order was successfully created.' }
          format.json { render :json => @documents_order, :status => :created, :location => @documents_order }
        else
          format.html { render :action => "new" }
          format.json { render :json => @documents_order.errors, :status => :unprocessable_entity }
        end
      end
    end
  
    # PUT /documents/orders/1
    # PUT /documents/orders/1.json
    def update
      @documents_order = Documents::Order.find(params[:id])
  
      respond_to do |format|
        if @documents_order.update_attributes(params[:documents_order])
          format.html { redirect_to @documents_order, :notice => 'Order was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @documents_order.errors, :status => :unprocessable_entity }
        end
      end
    end
  
    # DELETE /documents/orders/1
    # DELETE /documents/orders/1.json
    def destroy
      @documents_order = Documents::Order.find(params[:id])
      @documents_order.destroy
  
      respond_to do |format|
        format.html { redirect_to documents_orders_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/documents/orders_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::OrdersController < AccountsManagementController
    # GET /documents/orders
    # GET /documents/orders.json
    def index
      @documents_orders = Documents::Order.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @documents_orders }
      end
    end

    # GET /documents/orders/1
    # GET /documents/orders/1.json
    def show
      @documents_order = Documents::Order.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @documents_order }
      end
    end

    # GET /documents/orders/new
    # GET /documents/orders/new.json
    def new
      @documents_order = Documents::Order.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @documents_order }
      end
    end

    # GET /documents/orders/1/edit
    def edit
      @documents_order = Documents::Order.find(params[:id])
    end

    # POST /documents/orders
    # POST /documents/orders.json
    def create
      @documents_order = Documents::Order.new(params[:documents_order])

      respond_to do |format|
        if @documents_order.save
          format.html { redirect_to @documents_order, notice: 'Order was successfully created.' }
          format.json { render json: @documents_order, status: :created, location: @documents_order }
        else
          format.html { render action: "new" }
          format.json { render json: @documents_order.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /documents/orders/1
    # PUT /documents/orders/1.json
    def update
      @documents_order = Documents::Order.find(params[:id])

      respond_to do |format|
        if @documents_order.update_attributes(params[:documents_order])
          format.html { redirect_to @documents_order, notice: 'Order was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @documents_order.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/orders/1
    # DELETE /documents/orders/1.json
    def destroy
      @documents_order = Documents::Order.find(params[:id])
      @documents_order.destroy

      respond_to do |format|
        format.html { redirect_to documents_orders_url }
        format.json { head :no_content }
      end
    end
  end
end
